*I download and send audios of tracks/sets/albums in MP3 128 kbps with tags and artwork. Files over 50 MB are split into parts due to bot-sent file size limit. Supported sites:*
*• SoundCloud*: tracks/playlists/pages with private widgets
*• Bandcamp*: tracks/albums
*• YouTube*: videos/playlists
*• And pretty much everything from* [this list](https://rg3.github.io/youtube-dl/supportedsites.html)

*Usage:*
• Send a message with links to the chat and I will download them instantly in private or ask you in groups. [Privacy mode](https://core.telegram.org/bots#privacy-mode) is _disabled_ so I parse all group messages for links. Forwarded messages work too. For example:
`Check it out! https://m.soundcloud.com/richarddjames/umil-25-01 and also https://shitmat.bandcamp.com/track/amen-babylon-2016-mix`
• Use `/dl <link(-s)>` command to download instantly in groups.
• Use `/link <link(-s)>` command to get URL for downloading locally.

*Created by* @gpchelkin //[🐝👍.WS](http://xn--lo8h6c.ws/)
*With* 🖤 *for* @electrocircle //[⚡⚫.РФ](http://Электрокружок.РФ)
*Botpic by* @Lowonbudget //[👩‍🎨🖼️](https://www.behance.net/lowonbudget)
[🌟GitHub](https://github.com/gpchelkin/scdlbot) // [💻Issues](https://github.com/gpchelkin/scdlbot/issues)

Not mine: @vkm\_bot @scloud\_bot @GetMusicBot
